.. msprime documentation master file, created by
   sphinx-quickstart on Mon Jun  1 16:13:14 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to msprime's documentation!
===================================

This is the documentation for ``msprime``, a reimplementation of Hudson's
classical :command:`ms` simulator.

Contents:
=========

.. toctree::
   :maxdepth: 2

   introduction
   tutorial
   api
   cli
   file-format

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

